===============
Primer designer
===============

.. list-table::
    :stub-columns: 1

    * - tests
      - | |travis| |requires| |coveralls|
        | |quantified_code|
    * - package
      - |version| |wheel| |supported_versions| |supported_implementations|

.. |travis| image:: https://travis-ci.org/carlosp420/primer-designer.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/carlosp420/primer-designer

.. |requires| image:: https://requires.io/github/carlosp420/primer-designer/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/carlosp420/primer-designer/requirements/?branch=master

.. |coveralls| image:: https://coveralls.io/repos/carlosp420/primer-designer/badge.svg?branch=master&service=github
    :alt: Coverage Status
    :target: https://coveralls.io/r/carlosp420/primer-designer

.. |version| image:: https://img.shields.io/pypi/v/primer_designer.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/primer_designer

.. |quantified_code| image:: https://www.quantifiedcode.com/api/v1/project/23f9326bf0484aebb952f2d821969436/badge.svg
    :target: https://www.quantifiedcode.com/app/project/23f9326bf0484aebb952f2d821969436
    :alt: Code issues

.. |wheel| image:: https://img.shields.io/pypi/wheel/primer_designer.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/primer_designer

.. |supported_versions| image:: https://img.shields.io/pypi/pyversions/primer_designer.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/primer_designer

.. |supported_implementations| image:: https://img.shields.io/pypi/implementation/primer_designer.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/primer_designer

Designs primers from a FASTA file using primers4clades website

* Free software: BSD license

Installation
============

::

    pip install primer_designer

Documentation
=============

https://primer-designer.readthedocs.org/

Development
===========

To run the all tests run::

    tox
